summaryrefslogtreecommitdiff
path: root/modules/dnn
diff options
context:
space:
mode:
authorluz.paz <luzpaz@users.noreply.github.com>2018-02-12 07:07:39 -0500
committerluz.paz <luzpaz@users.noreply.github.com>2018-02-12 07:09:43 -0500
commit5718d09e392a79881ba723376ea9af211a3e7b3f (patch)
tree917d88a502affb4b35297e2e9c732be18c484896 /modules/dnn
parentb67523550f7c130332e5b5e538397897b195cb98 (diff)
downloadopencv-5718d09e392a79881ba723376ea9af211a3e7b3f.tar.gz
opencv-5718d09e392a79881ba723376ea9af211a3e7b3f.tar.bz2
opencv-5718d09e392a79881ba723376ea9af211a3e7b3f.zip
Misc. modules/ typos
Found via `codespell`
Diffstat (limited to 'modules/dnn')
-rw-r--r--modules/dnn/CMakeLists.txt2
-rw-r--r--modules/dnn/include/opencv2/dnn.hpp2
-rw-r--r--modules/dnn/include/opencv2/dnn/all_layers.hpp18
-rw-r--r--modules/dnn/include/opencv2/dnn/dnn.hpp4
-rw-r--r--modules/dnn/src/caffe/opencv-caffe.proto2
-rw-r--r--modules/dnn/src/dnn.cpp6
-rw-r--r--modules/dnn/src/layers/concat_layer.cpp2
-rw-r--r--modules/dnn/src/ocl4dnn/src/math_functions.cpp2
-rw-r--r--modules/dnn/src/opencl/conv_layer_spatial.cl4
-rw-r--r--modules/dnn/src/tensorflow/tf_importer.cpp4
-rw-r--r--modules/dnn/test/cityscapes_semsegm_test_enet.py4
-rw-r--r--modules/dnn/test/imagenet_cls_test_alexnet.py4
-rw-r--r--modules/dnn/test/imagenet_cls_test_googlenet.py4
-rw-r--r--modules/dnn/test/imagenet_cls_test_inception.py4
-rw-r--r--modules/dnn/test/pascal_semsegm_test_fcn.py2
15 files changed, 32 insertions, 32 deletions
diff --git a/modules/dnn/CMakeLists.txt b/modules/dnn/CMakeLists.txt
index 27717e1f5c..7971046851 100644
--- a/modules/dnn/CMakeLists.txt
+++ b/modules/dnn/CMakeLists.txt
@@ -41,7 +41,7 @@ endif()
add_definitions(-DHAVE_PROTOBUF=1)
-#supress warnings in autogenerated caffe.pb.* files
+#suppress warnings in autogenerated caffe.pb.* files
ocv_warnings_disable(CMAKE_CXX_FLAGS
-Wunused-parameter -Wundef -Wignored-qualifiers -Wno-enum-compare
-Wdeprecated-declarations
diff --git a/modules/dnn/include/opencv2/dnn.hpp b/modules/dnn/include/opencv2/dnn.hpp
index 690a82ab84..57a564bf11 100644
--- a/modules/dnn/include/opencv2/dnn.hpp
+++ b/modules/dnn/include/opencv2/dnn.hpp
@@ -53,7 +53,7 @@
- API for new layers creation, layers are building bricks of neural networks;
- set of built-in most-useful Layers;
- API to constuct and modify comprehensive neural networks from layers;
- - functionality for loading serialized networks models from differnet frameworks.
+ - functionality for loading serialized networks models from different frameworks.
Functionality of this module is designed only for forward pass computations (i. e. network testing).
A network training is in principle not supported.
diff --git a/modules/dnn/include/opencv2/dnn/dnn.hpp b/modules/dnn/include/opencv2/dnn/dnn.hpp
index 15c41b3079..4ad303594e 100644
--- a/modules/dnn/include/opencv2/dnn/dnn.hpp
+++ b/modules/dnn/include/opencv2/dnn/dnn.hpp
@@ -691,7 +691,7 @@ CV__DNN_EXPERIMENTAL_NS_BEGIN
* @param swapRB flag which indicates that swap first and last channels
* in 3-channel image is necessary.
* @param crop flag which indicates whether image will be cropped after resize or not
- * @details if @p crop is true, input image is resized so one side after resize is equal to corresponing
+ * @details if @p crop is true, input image is resized so one side after resize is equal to corresponding
* dimension in @p size and another one is equal or larger. Then, crop from the center is performed.
* If @p crop is false, direct resize without cropping and preserving aspect ratio is performed.
* @returns 4-dimansional Mat with NCHW dimensions order.
@@ -719,7 +719,7 @@ CV__DNN_EXPERIMENTAL_NS_BEGIN
* @param swapRB flag which indicates that swap first and last channels
* in 3-channel image is necessary.
* @param crop flag which indicates whether image will be cropped after resize or not
- * @details if @p crop is true, input image is resized so one side after resize is equal to corresponing
+ * @details if @p crop is true, input image is resized so one side after resize is equal to corresponding
* dimension in @p size and another one is equal or larger. Then, crop from the center is performed.
* If @p crop is false, direct resize without cropping and preserving aspect ratio is performed.
* @returns 4-dimansional Mat with NCHW dimensions order.
diff --git a/modules/dnn/src/caffe/opencv-caffe.proto b/modules/dnn/src/caffe/opencv-caffe.proto
index 88aaa86c22..41cd46bb1c 100644
--- a/modules/dnn/src/caffe/opencv-caffe.proto
+++ b/modules/dnn/src/caffe/opencv-caffe.proto
@@ -131,7 +131,7 @@ message PriorBoxParameter {
// Variance for adjusting the prior bboxes.
repeated float variance = 6;
// By default, we calculate img_height, img_width, step_x, step_y based on
- // bottom[0] (feat) and bottom[1] (img). Unless these values are explicitely
+ // bottom[0] (feat) and bottom[1] (img). Unless these values are explicitly
// provided.
// Explicitly provide the img_size.
optional uint32 img_size = 7;
diff --git a/modules/dnn/src/dnn.cpp b/modules/dnn/src/dnn.cpp
index be4767b28a..b66fb4236d 100644
--- a/modules/dnn/src/dnn.cpp
+++ b/modules/dnn/src/dnn.cpp
@@ -58,7 +58,7 @@ namespace cv {
namespace dnn {
CV__DNN_EXPERIMENTAL_NS_BEGIN
-// this option is usefull to run valgrind memory errors detection
+// this option is useful to run valgrind memory errors detection
static bool DNN_DISABLE_MEMORY_OPTIMIZATIONS = utils::getConfigurationParameterBool("OPENCV_DNN_DISABLE_MEMORY_OPTIMIZATIONS", false);
using std::vector;
@@ -911,7 +911,7 @@ struct Net::Impl
int id = getLayerId(layerName);
if (id < 0)
- CV_Error(Error::StsError, "Requsted layer \"" + layerName + "\" not found");
+ CV_Error(Error::StsError, "Requested layer \"" + layerName + "\" not found");
return getLayerData(id);
}
@@ -1897,7 +1897,7 @@ struct Net::Impl
if ((size_t)pin.oid >= ld.outputBlobs.size())
{
CV_Error(Error::StsOutOfRange, format("Layer \"%s\" produce only %d outputs, "
- "the #%d was requsted", ld.name.c_str(),
+ "the #%d was requested", ld.name.c_str(),
ld.outputBlobs.size(), pin.oid));
}
if (preferableTarget != DNN_TARGET_CPU)
diff --git a/modules/dnn/src/layers/concat_layer.cpp b/modules/dnn/src/layers/concat_layer.cpp
index f8c0a27dbe..63b722ee9a 100644
--- a/modules/dnn/src/layers/concat_layer.cpp
+++ b/modules/dnn/src/layers/concat_layer.cpp
@@ -88,7 +88,7 @@ public:
for (int curAxis = 0; curAxis < outputs[0].size(); curAxis++)
{
if (curAxis != cAxis && outputs[0][curAxis] != curShape[curAxis])
- CV_Error(Error::StsBadSize, "Inconsitent shape for ConcatLayer");
+ CV_Error(Error::StsBadSize, "Inconsistent shape for ConcatLayer");
}
}
diff --git a/modules/dnn/src/ocl4dnn/src/math_functions.cpp b/modules/dnn/src/ocl4dnn/src/math_functions.cpp
index c52a8a93c9..05cfd509b9 100644
--- a/modules/dnn/src/ocl4dnn/src/math_functions.cpp
+++ b/modules/dnn/src/ocl4dnn/src/math_functions.cpp
@@ -185,7 +185,7 @@ static bool ocl4dnnFastImageGEMM(const CBLAS_TRANSPOSE TransA,
int blockC_height = blocksize;
int use_buffer_indicator = 8;
- // To fix the edge problem casued by the sub group block read.
+ // To fix the edge problem caused by the sub group block read.
// we have to pad the image if it's not multiple of tile.
// just padding one line is enough as the sub group block read
// will clamp to edge according to the spec.
diff --git a/modules/dnn/src/opencl/conv_layer_spatial.cl b/modules/dnn/src/opencl/conv_layer_spatial.cl
index 3369c6c971..e31d173d75 100644
--- a/modules/dnn/src/opencl/conv_layer_spatial.cl
+++ b/modules/dnn/src/opencl/conv_layer_spatial.cl
@@ -188,7 +188,7 @@ __kernel void ConvolveBasic(
#define VLOAD4(_v, _p) do { _v = vload4(0, _p); } while(0)
// Each work-item computes a OUT_BLOCK_WIDTH * OUT_BLOCK_HEIGHT region of one output map.
-// Each work-group (which will be mapped to 1 SIMD16/SIMD8 EU thread) will compute 16/8 different feature maps, but each feature map is for the same region of the imput image.
+// Each work-group (which will be mapped to 1 SIMD16/SIMD8 EU thread) will compute 16/8 different feature maps, but each feature map is for the same region of the input image.
// NDRange: (output_width+pad)/ OUT_BLOCK_WIDTH, (output_height+pad)/OUT_BLOCK_HEIGHT, NUM_FILTERS/OUT_BLOCK_DEPTH
// NOTE: for beignet this reqd_work_group_size does not guarantee that SIMD16 mode will be used, the compiler could choose to use two SIMD8 threads, and if that happens the code will break.
@@ -220,7 +220,7 @@ convolve_simd(
int in_addr;
- // find weights adress of given neuron (lid is index)
+ // find weights address of given neuron (lid is index)
unsigned int weight_addr = (fmg % (ALIGNED_NUM_FILTERS/SIMD_SIZE)) * INPUT_DEPTH * KERNEL_WIDTH * KERNEL_HEIGHT * SIMD_SIZE + lid;
for(int i=0;i<OUT_BLOCK_SIZE;i++) {
diff --git a/modules/dnn/src/tensorflow/tf_importer.cpp b/modules/dnn/src/tensorflow/tf_importer.cpp
index ccb028ba1c..bc112d3560 100644
--- a/modules/dnn/src/tensorflow/tf_importer.cpp
+++ b/modules/dnn/src/tensorflow/tf_importer.cpp
@@ -1096,9 +1096,9 @@ void TFImporter::populateNet(Net dstNet)
dstNet.setInputsNames(netInputs);
}
else if (type == "Split") {
- // TODO: determing axis index remapping by input dimensions order of input blob
+ // TODO: determining axis index remapping by input dimensions order of input blob
// TODO: slicing input may be Const op
- // TODO: slicing kernels for convolutions - in current implenmentation it is impossible
+ // TODO: slicing kernels for convolutions - in current implementation it is impossible
// TODO: add parsing num of slices parameter
CV_Assert(layer.input_size() == 2);
// num_split
diff --git a/modules/dnn/test/cityscapes_semsegm_test_enet.py b/modules/dnn/test/cityscapes_semsegm_test_enet.py
index 5f0b4ba625..27070d3360 100644
--- a/modules/dnn/test/cityscapes_semsegm_test_enet.py
+++ b/modules/dnn/test/cityscapes_semsegm_test_enet.py
@@ -8,11 +8,11 @@ try:
import cv2 as cv
except ImportError:
raise ImportError('Can\'t find OpenCV Python module. If you\'ve built it from sources without installation, '
- 'configure environemnt variable PYTHONPATH to "opencv_build_dir/lib" directory (with "python3" subdirectory if required)')
+ 'configure environment variable PYTHONPATH to "opencv_build_dir/lib" directory (with "python3" subdirectory if required)')
try:
import torch
except ImportError:
- raise ImportError('Can\'t find pytorch. Please intall it by following instructions on the official site')
+ raise ImportError('Can\'t find pytorch. Please install it by following instructions on the official site')
from torch.utils.serialization import load_lua
from pascal_semsegm_test_fcn import eval_segm_result, get_conf_mat, get_metrics, DatasetImageFetch, SemSegmEvaluation
diff --git a/modules/dnn/test/imagenet_cls_test_alexnet.py b/modules/dnn/test/imagenet_cls_test_alexnet.py
index 46623b8ddf..49597d9540 100644
--- a/modules/dnn/test/imagenet_cls_test_alexnet.py
+++ b/modules/dnn/test/imagenet_cls_test_alexnet.py
@@ -9,12 +9,12 @@ try:
import caffe
except ImportError:
raise ImportError('Can\'t find Caffe Python module. If you\'ve built it from sources without installation, '
- 'configure environemnt variable PYTHONPATH to "git/caffe/python" directory')
+ 'configure environment variable PYTHONPATH to "git/caffe/python" directory')
try:
import cv2 as cv
except ImportError:
raise ImportError('Can\'t find OpenCV Python module. If you\'ve built it from sources without installation, '
- 'configure environemnt variable PYTHONPATH to "opencv_build_dir/lib" directory (with "python3" subdirectory if required)')
+ 'configure environment variable PYTHONPATH to "opencv_build_dir/lib" directory (with "python3" subdirectory if required)')
class DataFetch(object):
diff --git a/modules/dnn/test/imagenet_cls_test_googlenet.py b/modules/dnn/test/imagenet_cls_test_googlenet.py
index 6c7305b022..28f1abc2ff 100644
--- a/modules/dnn/test/imagenet_cls_test_googlenet.py
+++ b/modules/dnn/test/imagenet_cls_test_googlenet.py
@@ -7,12 +7,12 @@ try:
import caffe
except ImportError:
raise ImportError('Can\'t find Caffe Python module. If you\'ve built it from sources without installation, '
- 'configure environemnt variable PYTHONPATH to "git/caffe/python" directory')
+ 'configure environment variable PYTHONPATH to "git/caffe/python" directory')
try:
import cv2 as cv
except ImportError:
raise ImportError('Can\'t find OpenCV Python module. If you\'ve built it from sources without installation, '
- 'configure environemnt variable PYTHONPATH to "opencv_build_dir/lib" directory (with "python3" subdirectory if required)')
+ 'configure environment variable PYTHONPATH to "opencv_build_dir/lib" directory (with "python3" subdirectory if required)')
if __name__ == "__main__":
parser = argparse.ArgumentParser()
diff --git a/modules/dnn/test/imagenet_cls_test_inception.py b/modules/dnn/test/imagenet_cls_test_inception.py
index d6f0c55209..70017195be 100644
--- a/modules/dnn/test/imagenet_cls_test_inception.py
+++ b/modules/dnn/test/imagenet_cls_test_inception.py
@@ -9,10 +9,10 @@ try:
import cv2 as cv
except ImportError:
raise ImportError('Can\'t find OpenCV Python module. If you\'ve built it from sources without installation, '
- 'configure environemnt variable PYTHONPATH to "opencv_build_dir/lib" directory (with "python3" subdirectory if required)')
+ 'configure environment variable PYTHONPATH to "opencv_build_dir/lib" directory (with "python3" subdirectory if required)')
# If you've got an exception "Cannot load libmkl_avx.so or libmkl_def.so" or similar, try to export next variable
-# before runnigng the script:
+# before running the script:
# LD_PRELOAD=/opt/intel/mkl/lib/intel64/libmkl_core.so:/opt/intel/mkl/lib/intel64/libmkl_sequential.so
diff --git a/modules/dnn/test/pascal_semsegm_test_fcn.py b/modules/dnn/test/pascal_semsegm_test_fcn.py
index d855786a36..90fb050e0a 100644
--- a/modules/dnn/test/pascal_semsegm_test_fcn.py
+++ b/modules/dnn/test/pascal_semsegm_test_fcn.py
@@ -9,7 +9,7 @@ try:
import cv2 as cv
except ImportError:
raise ImportError('Can\'t find OpenCV Python module. If you\'ve built it from sources without installation, '
- 'configure environemnt variable PYTHONPATH to "opencv_build_dir/lib" directory (with "python3" subdirectory if required)')
+ 'configure environment variable PYTHONPATH to "opencv_build_dir/lib" directory (with "python3" subdirectory if required)')
def get_metrics(conf_mat):
diff --git a/modules/dnn/include/opencv2/dnn/all_layers.hpp b/modules/dnn/include/opencv2/dnn/all_layers.hpp
index 6741efaac1..061d184db6 100644
--- a/modules/dnn/include/opencv2/dnn/all_layers.hpp
+++ b/modules/dnn/include/opencv2/dnn/all_layers.hpp
@@ -51,13 +51,13 @@ CV__DNN_EXPERIMENTAL_NS_BEGIN
/** @defgroup dnnLayerList Partial List of Implemented Layers
@{
- This subsection of dnn module contains information about bult-in layers and their descriptions.
+ This subsection of dnn module contains information about built-in layers and their descriptions.
- Classes listed here, in fact, provides C++ API for creating intances of bult-in layers.
+ Classes listed here, in fact, provides C++ API for creating instances of built-in layers.
In addition to this way of layers instantiation, there is a more common factory API (see @ref dnnLayerFactory), it allows to create layers dynamically (by name) and register new ones.
- You can use both API, but factory API is less convinient for native C++ programming and basically designed for use inside importers (see @ref readNetFromCaffe(), @ref readNetFromTorch(), @ref readNetFromTensorflow()).
+ You can use both API, but factory API is less convenient for native C++ programming and basically designed for use inside importers (see @ref readNetFromCaffe(), @ref readNetFromTorch(), @ref readNetFromTensorflow()).
- Bult-in layers partially reproduce functionality of corresponding Caffe and Torch7 layers.
+ Built-in layers partially reproduce functionality of corresponding Caffe and Torch7 layers.
In partuclar, the following layers and Caffe importer were tested to reproduce <a href="http://caffe.berkeleyvision.org/tutorial/layers.html">Caffe</a> functionality:
- Convolution
- Deconvolution
@@ -125,12 +125,12 @@ CV__DNN_EXPERIMENTAL_NS_BEGIN
virtual void setOutShape(const MatShape &outTailShape = MatShape()) = 0;
/** @deprecated Use flag `produce_cell_output` in LayerParams.
- * @brief Specifies either interpet first dimension of input blob as timestamp dimenion either as sample.
+ * @brief Specifies either interpret first dimension of input blob as timestamp dimenion either as sample.
*
- * If flag is set to true then shape of input blob will be interpeted as [`T`, `N`, `[data dims]`] where `T` specifies number of timpestamps, `N` is number of independent streams.
+ * If flag is set to true then shape of input blob will be interpreted as [`T`, `N`, `[data dims]`] where `T` specifies number of timestamps, `N` is number of independent streams.
* In this case each forward() call will iterate through `T` timestamps and update layer's state `T` times.
*
- * If flag is set to false then shape of input blob will be interpeted as [`N`, `[data dims]`].
+ * If flag is set to false then shape of input blob will be interpreted as [`N`, `[data dims]`].
* In this case each forward() call will make one iteration and produce one timestamp with shape [`N`, `[out dims]`].
*/
CV_DEPRECATED virtual void setUseTimstampsDim(bool use = true) = 0;
@@ -146,7 +146,7 @@ CV__DNN_EXPERIMENTAL_NS_BEGIN
* @param output contains computed outputs: @f$h_t@f$ (and @f$c_t@f$ if setProduceCellOutput() flag was set to true).
*
* If setUseTimstampsDim() is set to true then @p input[0] should has at least two dimensions with the following shape: [`T`, `N`, `[data dims]`],
- * where `T` specifies number of timpestamps, `N` is number of independent streams (i.e. @f$ x_{t_0 + t}^{stream} @f$ is stored inside @p input[0][t, stream, ...]).
+ * where `T` specifies number of timestamps, `N` is number of independent streams (i.e. @f$ x_{t_0 + t}^{stream} @f$ is stored inside @p input[0][t, stream, ...]).
*
* If setUseTimstampsDim() is set to fase then @p input[0] should contain single timestamp, its shape should has form [`N`, `[data dims]`] with at least one dimension.
* (i.e. @f$ x_{t}^{stream} @f$ is stored inside @p input[0][stream, ...]).
@@ -328,7 +328,7 @@ CV__DNN_EXPERIMENTAL_NS_BEGIN
* @param begin Vector of start indices
* @param size Vector of sizes
*
* More convinient numpy-like slice. One and only output blob
* is a slice `input[begin[0]:begin[0]+size[0], begin[1]:begin[1]+size[1], ...]`
*
* 3. Torch mode
@@ -328,7 +328,7 @@ CV__DNN_EXPERIMENTAL_NS_BEGIN
* @param size Vector of sizes
*
- * More convinient numpy-like slice. One and only output blob
+ * More convenient numpy-like slice. One and only output blob
* is a slice `input[begin[0]:begin[0]+size[0], begin[1]:begin[1]+size[1], ...]`
*